Method: Sequelizer::ConnectionMaker#initialize
- Defined in:
- lib/sequelizer/connection_maker.rb
#initialize(options = nil) ⇒ ConnectionMaker
Accepts an optional set of database options
If no options are provided, attempts to read options from config/database.yml
If config/database.yml doesn’t exist, Dotenv is used to try to load a .env file, then uses any SEQUELIZER_* environment variables as database options
19 20 21 |
# File 'lib/sequelizer/connection_maker.rb', line 19 def initialize( = nil) = Options.new() end |